@@ -16,7 +16,7 @@ use themelio_structs::{
     TxKind,
 };
 
-use crate::walletdata::WalletData;
+use crate::walletdata::LegacyWalletData;
 
 use self::pool::ConnPool;
 
@@ -118,7 +118,7 @@ impl Database {
     }
 
     /// Restore a wallet dump.
-    pub async fn restore_wallet_dump(&self, name: &str, dump: WalletData) {
+    pub async fn restore_wallet_dump(&self, name: &str, dump: LegacyWalletData) {
         let mut conn = self.pool.get_conn().await;
         let txn = conn.transaction().unwrap();
         for (cid, cdh) in dump.unspent_coins.into_iter() {
@@ -282,7 +282,7 @@ impl Wallet {
             )
             .unwrap();
         let mut rows = stmt.query(params![self.covhash.to_string()]).unwrap();
-        let mut toret = HashMap::new();
+        let mut toret = BTreeMap::new();
         while let Ok(Some(row)) = rows.next() {
             let coinid: String = row.get(0).unwrap();
             let coinid: CoinID = coinid.parse().unwrap();
@@ -294,8 +294,9 @@ impl Wallet {
             }
             toret.insert(coinid.txhash, height.map(|h| h.into()));
         }
+        // we then go through le pending
         let mut out = toret.into_iter().collect::<Vec<_>>();
-        out.sort_unstable_by_key(|x| x.1);
+        out.sort_by_key(|x| x.1);
         out
     }
 
@@ -689,12 +690,10 @@ impl Wallet {
             } else {
                 let snapshot = snapshot.clone();
                 let task = smolscale::spawn(async move {
-                    let start = Instant::now();
-                    let res = snapshot
+                    snapshot
                         .get_coin(coinid)
                         .await?
-                        .context("self-contradictory coin list");
-                    res
+                        .context("self-contradictory coin list")
                 });
                 potential_coins.push((coinid, task));
             }
