@@ -9,7 +9,7 @@ use std::{collections::BTreeMap, ffi::CString, net::SocketAddr, path::PathBuf, s
 use anyhow::Context;
 use base32::Alphabet;
 use http_types::headers::HeaderValue;
-use multi::MultiWallet;
+use multi::LegacyMultiWallet;
 use serde::{Deserialize, Serialize};
 use state::AppState;
 use std::fmt::Debug;
@@ -77,7 +77,7 @@ fn main() -> anyhow::Result<()> {
                 0o700,
             );
         }
-        let multiwallet = MultiWallet::open(&args.wallet_dir)?;
+        let multiwallet = LegacyMultiWallet::open(&args.wallet_dir)?;
         log::info!(
             "opened LEGACY wallet directory: {:?}",
             multiwallet.list().collect::<Vec<_>>()
@@ -210,7 +210,7 @@ async fn get_pool(req: Request<Arc<AppState>>) -> tide::Result<Body> {
     let client = req.state().client(network).clone();
     let pool_key: PoolKey = req
         .param("pair")?
-        .replace(":", "/")
+        .replace(':', "/")
         .parse()
         .map_err(to_badreq)?;
     let pool_key = pool_key
@@ -541,12 +541,12 @@ async fn get_tx_balance(req: Request<Arc<AppState>>) -> tide::Result<Body> {
     let self_originated = raw.covenants.iter().any(|c| c.hash() == wallet.address().0);
     // Total balance out
     let mut balance: BTreeMap<String, i128> = BTreeMap::new();
-    // // Add all outputs to balance
-    // if self_originated {
-    //     *balance
-    //         .entry(hex::encode(Denom::Mel.to_bytes()))
-    //         .or_default() -= raw.fee.0 as i128;
-    // }
+    // Add all outputs to balance
+    if self_originated {
+        *balance
+            .entry(hex::encode(Denom::Mel.to_bytes()))
+            .or_default() -= raw.fee.0 as i128;
+    }
     for (idx, output) in raw.outputs.iter().enumerate() {
         let coinid = raw.output_coinid(idx as u8);
         let denom_key = hex::encode(output.denom.to_bytes());
@@ -562,7 +562,7 @@ async fn get_tx_balance(req: Request<Arc<AppState>>) -> tide::Result<Body> {
             }
         }
     }
-    Body::from_json(&(self_originated, balance))
+    Body::from_json(&(self_originated, raw.kind, balance))
 }
 
 async fn get_tx(req: Request<Arc<AppState>>) -> tide::Result<Body> {
